@@ -4,34 +4,25 @@ package LiveGeez::File;
 BEGIN
 {
 	use strict;
-	use vars qw($VERSION $DIRMASK @itoa64 @gFile $RC_OK $RC_NOT_MODIFIED);
+	use vars qw($VERSION $DIRMASK @itoa64 @gFile);
 
-	$VERSION = '0.20';
+	$VERSION = '0.14';
 
 	require 5.000;
 
-	# use LiveGeez::Config;
+	use LiveGeez::Local;
 	use LiveGeez::HTML;
 
-	require LiveGeez::URI;
-	require LiveGeez::CacheAsSERA;
-
-	# if ( $PROCESSURLS ) {
-	#	use LWP::Simple;
-	# }
+	if ( $processURLs ) {
+		require LiveGeez::CacheAsSERA;
+		use LWP::Simple;
+	}
 	#
 	# Uncomment these next 3 if using getURL command
 	#
 	# use LWP::UserAgent;
 	# use HTTP::Request;
 	# use HTTP::Response;
-	# use File::Path 'mkpath';
-	require File::Path;
-	require Apache::File;
-	require Compress::Zlib;
-	require LWP::Simple;
-	require POSIX;
-
 	$DIRMASK = "0755";
 
 	@itoa64 = split ( //, "./0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz" );
@@ -43,9 +34,6 @@ BEGIN
 #
 $#gFile = 100;	# preset to one hundred lines, most articles should be
 		# smaller than this.
-
-	$RC_OK           = LWP::Simple::RC_OK();
-	$RC_NOT_MODIFIED = LWP::Simple::RC_NOT_MODIFIED();
 }
 
 
@@ -54,65 +42,43 @@ $#gFile = 100;	# preset to one hundred lines, most articles should be
 sub new
 {
 my $class   = shift;
+my $request = shift;
 my $self    = {};
 
 
-	my $blessing = bless $self, $class;
-
-	$self->_init_sysOut ( @_ );
-
-	$self->OpenFile;
-
-	$blessing;
-
-}
-
-
-sub _init_sysOut
-{
-my ( $self, $request ) = @_;
-
+	#
+	# what else could we test for?
+	#
+	$request->{file} .= "/"
+		if ( $request->{file} !~ /htm(l)?$/i && $request->{file} !~ /\/$/ );
 
 	#
 	# this isn't a good test, check the Content-Type type.
 	#
 	# $request->DieCgi ( "Unrecognized file type, does not appear to be HTML<br>$request->{file}" )
-	# 	if ( $request->{file} !~ /\.x\w{3,}$/i && $request->{file} !~ /\/$/ );
-
+	# 	if ( $request->{file} !~ /htm(l)?$/i && $request->{file} !~ /\/$/ );
 
 	$self->{request}     =   $request;
 
 	$self->{fileSysOut}  =   $request->{sysOut}->{sysName};
-
 	$self->{fileSysOut} .= ".$request->{sysOut}->{xfer}"
 				 if ( $request->{sysOut}->{xfer} ne "notv" );
-
 	$self->{fileSysOut} .= ".7-bit"
-				 if ( $request->{sysOut}->{'7-bit'} eq "true" );
-
+				 if ( $request->{sysOut}->{'7-bit'} );
 	$self->{fileSysOut} .= ".$request->{sysOut}->{options}"
 				 if ( $request->{sysOut}->{options} );
-
-	$self->{fileSysOut} .= ".$request->{WebFont}" if ( $request->{WebFont} );
-
-	$self->{fileSysOut} .= ".$request->{sysOut}->{lang}" unless ( $request->{file} =~ /\.$request->{sysOut}->{lang}\./ );
-
+	$self->{fileSysOut} .= ".$request->{sysOut}->{lang}";
 	$self->{fileSysOut} .= ".NoFrames"
 				 if ( $request->{frames} eq "no" );
-
 	$self->{fileSysOut} .= ".FirstTime"
 				 if ( $request->{FirstTime} );
 
-	$self->{scriptRoot} = ( $self->{request}->{uri}->scheme ) 
-	                      ? $self->{request}->{config}->{uris}->{zuri} 
-	                      : $self->{request}->{config}->{uris}->{zpath}
-	                    ;
-	$self->{isCGI}       =   0;
+	my $blessing = bless $self, $class;
 
-	$self->{refsUpdated} =   0;
+	$self->OpenFile;
+
+	$blessing;
 
-	$self->{baseUpdated} =   0;
-1;
 }
 
 
@@ -139,13 +105,15 @@ sub myRand
 sub OpenFile
 {
 my $self = shift;
+my $file = $self->{request}->{file};
 my ( $sourceFile, $fileStream, $fileIsURL );
 
 
 	#
 	# check if file is a URL, if not strip off leading "/" if any.
 	#
-	$self->{isRemote} = ( $self->{request}->{uri}->scheme ) ? 1 : 0;
+	$file =~ s#^/##
+	unless ( ($fileIsURL = ( $file =~ m#^(\w)+://# )) );
 
 
 	#
@@ -154,13 +122,14 @@ my ( $sourceFile, $fileStream, $fileIsURL );
 	# processing...
 	#
 	$self->{request}->DieCgi ( "Sorry!  Zobel at $scriptURL is for local use only!\n" )
-		if ( $self->{isRemote} && !$self->{request}->{config}->{processurls} );
+		if ( $fileIsURL && !$processURLs );
 
+	$self->{isRemote} = $fileIsURL;
 
 	#
 	# check if cached.
 	#
-	$sourceFile = ( $self->{isRemote} ) ? $self->CheckCacheURL : $self->CheckCacheFile;
+	$sourceFile = ( $fileIsURL ) ? $self->CheckCacheURL : $self->CheckCacheFile;
 
 	$self->{request}->DieCgiWithEMail ( "The requested file '$self->{request}->{file}' was not found.", "$self->{request}->{file} not found" )
 		unless ( $sourceFile );
@@ -171,8 +140,24 @@ my ( $sourceFile, $fileStream, $fileIsURL );
 	return if ( $self->{isCached} );
 
 
+	#
+	# otherwise read file into our "@gFile" buffer;
+	#
+	$fileStream = ($self->{isZipped}) ? "gzip -d --stdout $sourceFile |" : "$sourceFile";
 
-	1;
+	open (FILE, "$fileStream") || $self->{request}->DieCgi
+	     ( "!: Could Not Open File: $sourceFile!\n" );
+
+	#
+	# cute one-liner but turns out to be inefficient because the string has
+	# to grow with each new line read, so we use a package-local presized array.
+	#
+	# $self->{htmlData} = join ( "", <FILE> );
+
+	@gFile = <FILE>;
+	$self->{htmlData} = join ( "", @gFile );
+
+	close ( FILE );
 
 }
 
@@ -187,73 +172,29 @@ my $self = shift;
 	#
 	if ( $self->{isCached} ) {
 		$self->DisplayFromCache;
+		return;
 	}
 	elsif ( $self->{useSource} ) {
-		$self->DisplayFromSource;
+	 	$self->{request}{'x-gzip'} = 0;
+	 	$self->{request}->HeaderPrint;
+	 	$self->{request}->print ( $self->{htmlData} );
+	 	return;
 	}
-	else {
 
-		#
-		# Translate buffer.
-		#
-		FileBuffer ( $self );
-
-
-		#
-		# finally, display and cache the results.
-		#
-		if ( $self->{isCGI} ) {
-			$self->DisplayFileDontCache;
-			unlink ( $self->{uris}->{source} );
-			unlink ( $self->{uris}->{tmpFile} );
-		}
-		elsif ( $self->{dontCache} ) {  # probably a date="today"
-			$self->DisplayFileDontCache;
-		}
-		else {
-			$self->DisplayFileAndCache;
-		}
-
-
-		delete ( $self->{htmlData} );
-	}
-}
-
-
-sub DisplayFromSource
-{
-my $self = shift;
-
-
-	my $sourceFile = $self->{uris}->{source};
 
 	#
-	# if no modification, then redirect to source URL, if not cached
+	# Translate buffer.
 	#
+	FileBuffer ($self);
 
 
-	my $fileStream 
-	= ( ( $self->{isZipped} && $self->{request}->{'x-gzip'} ) || !$self->{isZipped} )
-	  ? $sourceFile
-	  : "gzip -d --stdout $sourceFile |"
-	;
+	#
+	# finally, display and cache the results.
+	#
+	$self->DisplayFileAndCache;
 
-	open (SOURCEFILE, "$fileStream") || $self->{request}->DieCgi
-	     ( "!: Could Not Open File: $sourceFile!\n" );
-
-	$self->{request}->HeaderPrint;
-
-	if ( !$self->{isZipped} && $self->{request}->{'x-gzip'} ) {
-		local $/;
-		$self->{request}->print ( Compress::Zlib::memGzip( <SOURCEFILE> ) );
-	}
-	else {
-		$self->{request}->print ( <SOURCEFILE> );
-	}
-
-	close ( SOURCEFILE );
-
-	1;
+	$#gFile = -1;
+	delete ( $self->{htmlData} );
 }
 
 
@@ -269,22 +210,16 @@ my $self = shift;
 #	require frame elements to be stored in a "Frames" subdirectory).
 #
 #------------------------------------------------------------------------------#
-sub DisplayFileAndCacheX
+sub DisplayFileAndCache
 {
 my $self = shift;
-my $cacheFile = $self->{uris}->{cachein};
+my $cacheFile = $self->{cacheFileIn};
 
 
+	$self->{request}->{'x-gzip'} = 0;
 	$self->{request}->HeaderPrint;
-
-	if ( $self->{request}->{apache} ) {
-		if ( $self->{request}->{'x-gzip'} ) {
-			local $/;
-			$self->{request}->{apache}->print ( Compress::Zlib::memGzip( $self->{htmlData} ) );
-		}
-		else {
-			$self->{request}->{apache}->print ( $self->{htmlData} );
-		}
+	if ( $useApache ) {
+		$self->{request}->{apache}->print ( $self->{htmlData} );
 		open (CACHEFILE, ">$cacheFile") 
 		|| $self->{request}->DieCgi ( "!: Can't Open $cacheFile!\n" );
 	}
@@ -292,68 +227,13 @@ my $cacheFile = $self->{uris}->{cachein};
 		open (CACHEFILE, "| tee $cacheFile") 
 		|| $self->{request}->DieCgi ( "!: Can't Open $cacheFile!\n" );
 	}
-
 	print CACHEFILE $self->{htmlData};
-
 	close (CACHEFILE);
 
 	system ( 'gzip', '-f', $cacheFile ) if ( $cacheFile !~ /\/Frames/ );
 
 	1;
 }
-sub DisplayFileAndCache
-{
-my $self = shift;
-my $cacheFile = $self->{uris}->{cachein};
-
-
-	$self->{request}->HeaderPrint;
-
-	if ( $self->{request}->{'x-gzip'} ) {
-		local $/;
-		$self->{request}->print ( Compress::Zlib::memGzip( $self->{htmlData} ) );
-		open (CACHEFILE, ">$cacheFile") 
-		|| $self->{request}->DieCgi ( "!: Can't Open $cacheFile!\n" );
-	}
-	else {
-		if ( $self->{request}->{apache} ) {
-			$self->{request}->{apache}->print ( $self->{htmlData} );
-			open (CACHEFILE, ">$cacheFile") 
-				|| $self->{request}->DieCgi ( "!: Can't Open $cacheFile!\n" );
-		}
-		else {
-			open (CACHEFILE, "| tee $cacheFile") 
-			|| $self->{request}->DieCgi ( "!: Can't Open $cacheFile!\n" );
-		}
-	}
-
-	print CACHEFILE $self->{htmlData};
-
-	close (CACHEFILE);
-
-	system ( 'gzip', '-f', $cacheFile ) if ( $cacheFile !~ /\/Frames/ );
-
-	1;
-}
-
-
-sub DisplayFileDontCache
-{
-my $self = shift;
-
-
-	$self->{request}->HeaderPrint;
-	
-	if ( $self->{request}->{'x-gzip'} ) {
-		local $/;
-		$self->{request}->print ( Compress::Zlib::memGzip( $self->{htmlData} ) );
-	}
-	else {
-		$self->{request}->print ( $self->{htmlData} );
-	}
-
-	1;
-}
 
 
 #------------------------------------------------------------------------------#
@@ -417,50 +297,35 @@ my $responseCode;
 sub CheckCacheFile
 {
 my $self = shift;
-my ( $dir, $file, $diskFile, $cacheDir, $cacheFileIn, $cacheFileOut, $sourceFile, $ext );
+my $diskFile = $self->{request}->{file};
+my ( $dir, $file, $cacheDir, $cacheFileIn, $cacheFileOut, $sourceFile, $ext );
 
-	$self->{doc_root} = ( $self->{request}->{config}->{set_local_base} )
-	? $self->{request}->{config}->{set_local_base} . "/"
-	: 0
-	;
-	
 
-	$diskFile = $self->{request}->{uri}->path;
+	($file, $dir) = split ( m#/#, reverse($diskFile), 2 );
+	$dir = reverse($dir);
+	$dir =~ s|^/||;
 
-	$file = $self->{request}->{uri}->file;
-
-	unless ( $file ) {
-		# we were passed a directory reference
-		# so for caching purposes we'll use "index.html"
-		if ( -e ("$self->{request}->{config}->{uris}->{webroot}/$diskFile/index.sera.html") ) {
-			$diskFile .= "/index.sera.html";
-		}
-		elsif ( -e ("$self->{request}->{config}->{uris}->{webroot}/$diskFile/index.html") ) {
-			$diskFile .= "/index.html";
-		} elsif ( -e ("$self->{request}->{config}->{uris}->{webroot}/$diskFile/index.htm") ) {
-			$diskFile .= "/index.htm";
-		}
-		$file = "index.html";
+	if ( $file ) {
+		$file = reverse($file);
+		$file =~ s/[ ()]/_/g;
 	}
 	else {
-		$diskFile =~ s|^/||;
-	}
-
-	#
-	#  Look for a language specific index if we are dealing with an index
-	#
-	if ( $diskFile =~ /index\..*?\.htm(l)?$/o
-	     && $diskFile !~ /\.$request->{sysOut}->{lang}\./ ) {
-		my $langIndex = $diskFile;
-		$langIndex =~ s/index/index.$self->{request}->{sysOut}->{lang}/;
-		$diskFile = $langIndex
-		if ( -e ("$self->{request}->{config}->{uris}->{webroot}/$langIndex") );
+		# we were passed a directory reference
+		# so for caching purposes we'll use "index.html"
+		if ( -e ("$webRoot/$diskFile/index.html") ) {
+			$diskFile .= "/index.html";
+		} elsif ( -e ("$webRoot/$diskFile/index.htm") ) {
+			$diskFile .= "/index.htm";
+		} elsif ( -e ("$webRoot/$diskFile/index.sera.html") ) {
+			$diskFile .= "/index.sera.html";
+		}
+		$file = "index.html";
 	}
 
 	#
 	#  Alas the sourceFile that we are working with
 	#
-	$sourceFile = "$self->{request}->{config}->{uris}->{webroot}/$diskFile";
+	$sourceFile = "$webRoot/$diskFile";
 
 	unless ( (-e $sourceFile) ) {
 		if ( (-e "$sourceFile.gz") ) {
@@ -468,7 +333,7 @@ my ( $dir, $file, $diskFile, $cacheDir, $cacheFileIn, $cacheFileOut, $sourceFile
 			$sourceFile .= ".gz";
 		}
 		else {
-			return;
+			return undef;
 		}
 	}
 
@@ -477,25 +342,24 @@ my ( $dir, $file, $diskFile, $cacheDir, $cacheFileIn, $cacheFileOut, $sourceFile
 	#
 	if ( $self->{request}->{sysIn}->{sysName} eq $self->{request}->{sysOut}->{sysName} ) {
 		$self->{useSource} = 1;
-		return ( $self->{uris}->{source} = $sourceFile );
+		return ( $self->{sourceFile} = $sourceFile );
 	}
 
+	$self->{baseDomain} = "$dir" if ( $dir );
 
-	$file = $self->{request}->{uri}->file_base || "index";  # no ext
-	$dir  = $self->{request}->{uri}->dir_clean;
-	$ext  = $self->{ext} = $self->{request}->{uri}->ext || "html";
+	$file =~ s/\.(htm(l)?)$//oi;
+	$ext  =  $1;
+	$file =~ s/\.sera$//i;
 
-	$file   =~ s/\.sera$//i;
-
-	$cacheDir     = "$self->{request}->{config}->{uris}->{cachelocal}";
-	$cacheDir    .= "/$dir" if ( $dir );
+	$dir          =~ s/[ ()]/_/g;
+	$cacheDir     = "$FileCacheDir/$dir";
 	$cacheFileIn  = "$cacheDir/$file.$self->{fileSysOut}.$ext";
 	$cacheFileOut =  ( $diskFile !~ /\/Frames/ )
 	              ? "$cacheDir/$file.$self->{fileSysOut}.$ext.gz"
 	              :  $cacheFileIn
 	              ;
 
-	$self->{uris}->{cachein} = $cacheFileIn;
+	$self->{cacheFileIn} = $cacheFileIn;
 
 	unlink ( $cacheFileOut ) if ( $self->{request}->{'no-cache'} );
 
@@ -503,8 +367,8 @@ my ( $dir, $file, $diskFile, $cacheDir, $cacheFileIn, $cacheFileOut, $sourceFile
 		#
 		#  Check Date Here
 		#
-		if ( $self->{request}->{config}->{checkfiledates}
-		     && ( (stat ( $cacheFileOut ))[9] < (stat ( $sourceFile ))[9] ) )
+		if ( $checkFileDates
+			 && ( (stat ( $cacheFileOut ))[9] < (stat ( $sourceFile ))[9] ) )
 	 	{
 			#
 			#  if old delete and get New
@@ -514,37 +378,26 @@ my ( $dir, $file, $diskFile, $cacheDir, $cacheFileIn, $cacheFileOut, $sourceFile
 			#
 			#  is sourceFile in SERA?
 			#
-		#	$sourceFile = LiveGeez::CacheAsSERA::HTML ( $self, $sourceFile )
-		#		unless ( $self->{request}->{sysIn}->{sysName} eq "sera" );
-			$sourceFile = ( $self->{request}->{sysIn}->{sysName} eq "sera" )
-			              ? LiveGeez::CacheAsSERA::Local ( $self, $sourceFile )
-			              : LiveGeez::CacheAsSERA::Remote ( $self, $sourceFile )
-			                unless ( $self->{request}->{cache_check_override} )
-			            ;
+			$sourceFile = LiveGeez::CacheAsSERA::HTML ( $self, $sourceFile )
+				unless ( $self->{request}->{sysIn}->{sysName} eq "sera" );
 		}
 		else {
 			$sourceFile = $cacheFileOut;
 			$self->{isCached} = "true";
 			$self->{isZipped} = "true" if ( $cacheFileOut ne $cacheFileIn );
 		}
-		$self->{uris}->{cacheout} = $cacheFileOut;
+		$self->{cacheFileOut} = $cacheFileOut;
 	}
 	else {
 		MakeCacheDir ($cacheDir, $FileCacheDir);
 		#
 		#  is sourceFile in SERA?
 		#
-		# $sourceFile = LiveGeez::CacheAsSERA::HTML ( $self, $sourceFile )
-		# 	unless ( $self->{request}->{sysIn}->{sysName} eq "sera" );
-		$sourceFile = ( $self->{request}->{sysIn}->{sysName} eq "sera" )
-		              ? LiveGeez::CacheAsSERA::Local ( $self, $sourceFile )
-		              : LiveGeez::CacheAsSERA::Remote ( $self, $sourceFile )
-		                unless ( $self->{request}->{cache_check_override} )
-		            ;
-		$self->{request}->{sysIn} = $LiveGeez::CacheAsSERA::s;
+		$sourceFile = LiveGeez::CacheAsSERA::HTML ( $self, $sourceFile )
+			unless ( $self->{request}->{sysIn}->{sysName} eq "sera" );
 	}
 
-	$self->{uris}->{source} = $sourceFile;
+	$self->{sourceFile} = $sourceFile;
 
 }
 
@@ -560,30 +413,44 @@ my ( $dir, $file, $diskFile, $cacheDir, $cacheFileIn, $cacheFileOut, $sourceFile
 sub CheckCacheURL
 {
 my $self = shift;
-my ( $dir, $file, $cacheDir, $cacheFileIn, $cacheFileOut, $ext );
-
-# use LWP::Simple;  # presumably this load only once and only if we reach here
+my $URL  = $self->{request}->{file};
+my ( $proto, $url, $dir, $file, $cacheDir, $cacheFileIn, $cacheFileOut, $ext, $baseURL );
 
 
-	$file = $self->{request}->{uri}->file_clean || "index.html";
-	$dir  = $self->{request}->{uri}->dir_clean;
-	$ext  = $self->{ext} = $self->{request}->{uri}->ext || "html";
+	($proto,$url) = split ( m#//#, $URL, 2 );
+	($url,  $dir) = split ( m#/#, $url, 2 );
+	($file, $dir) = split ( m#/#, reverse($dir), 2 );
 
-	$self->{uri_authority} = $self->{request}->{uri}->scheme_authority;
-	$self->{doc_root}      = $self->{request}->{uri}->doc_root . "/";
+	chop ($proto);
+	$dir = reverse($dir);
+	$url = lc($url);
+	$baseURL = "$proto://$url/$dir/";
+	$self->{baseDomain}  = "$proto://$url/";
+	$self->{baseDomain} .= "$1" if ( $dir =~ /^(~[^\/]+)/ );
 
-	$cacheDir   = "$self->{request}->{config}->{uris}->{cacheremote}/".$self->{request}->{uri}->host.$dir;
+	if ( $file ) {
+		$file = reverse($file);
+		$file =~ s/[ ()]/_/g;
+	}
+	else {
+		# we were passed a directory reference
+		# so for caching purposes we'll use "index.html"
+		$file = "index.html";
+	}
+
+	$dir        =~ s/[ ()]/_/g;
+	$cacheDir   = "$URLCacheDir/$url/$dir";
 	$sourceFile = "$cacheDir/$file";
 
+	$file       =~ s/\.(htm(l)?)$//oi;
+	$ext        =  $1;
+	$file       =~ s/\.sera$//i;
 
-	$file = $self->{request}->{uri}->file_base || "index";  # no terminal ext
+	$cacheFileIn         = "$cacheDir/$file.$self->{fileSysOut}.$ext";
+	$cacheFileOut        = "$cacheDir/$file.$self->{fileSysOut}.$ext.gz";
 
-	$file   =~ s/\.sera$//i;
-
-	$cacheFileIn  = "$cacheDir/$file.$self->{fileSysOut}.$ext";
-	$cacheFileOut = $cacheFileIn.".gz";
-
-	$self->{uris}->{cachein} = $cacheFileIn;
+	$self->{baseURL}     = $baseURL;
+	$self->{cacheFileIn} = $cacheFileIn;
 
 	unlink <$cacheDir/$file*>
 		if ( $self->{request}->{'no-cache'} );
@@ -593,12 +460,12 @@ my ( $dir, $file, $cacheDir, $cacheFileIn, $cacheFileOut, $ext );
 	# If the file is cached we will compare the file date against the
 	# version on the server
 	#
-	if (-e $sourceFile) {
+	if (-e $cacheFileOut) {
 		# my ($mtime) = (stat($cacheFileOut))[9];
 		# my ($cacheDate) = HTTP::Date::time2str($mtime);
 
-		my $rc = LWP::Simple::mirror ($self->{request}->{file}, $sourceFile);
-		if ( $rc == $RC_OK ) {
+		my $rc = mirror ($URL, $sourceFile);
+		if ( $rc == RC_OK ) {
 			# Clear cache
 			my $output = unlink <$cacheDir/$file*gz>;
 			
@@ -614,56 +481,44 @@ my ( $dir, $file, $cacheDir, $cacheFileIn, $cacheFileOut, $ext );
 			#
 			#  is sourceFile in SERA?
 			#
-			# $sourceFile = LiveGeez::CacheAsSERA::HTML ( $self, $sourceFile );
-				# unless ( $self->{request}->{sysIn} && ($self->{request}->{sysIn}->{sysName} eq "sera") );
+			$sourceFile = LiveGeez::CacheAsSERA::HTML ( $self, $sourceFile )
+				unless ( $self->{request}->{sysIn}->{sysName} eq "sera" );
 
-			# return ( $self->{uris}->{source} = $sourceFile );
+			return ( $self->{sourceFile} = $sourceFile );
+		}
+		elsif ( $rc != RC_NOT_MODIFIED ) {
+			return undef;
 		}
-		# elsif ( $rc != $RC_NOT_MODIFIED ) {
-		# 	return;
-		# }
-		# continue and use present version
 
 		# Use present cache file, we assume a 304
-		if ( -e $cacheFileOut ) {
-			$self->{isZipped} = $self->{isCached} = "true";
-			$self->{uris}->{cacheout} = $sourceFile = $cacheFileOut;
-		}
-		else {
-			$sourceFile = LiveGeez::CacheAsSERA::Remote ( $self, $sourceFile );
-		}
+		$self->{isZipped} = $self->{isCached} = "true";
+		$self->{cacheFileOut} = $sourceFile = $cacheFileOut;
 	
 	}
 	else {
-		# use POSIX qw(strftime);
+		use POSIX qw(strftime);
 
-		my $tempFile = "$self->{request}->{config}->{uris}->{cacheremote}/tmp."
-		             . POSIX::strftime ( '%m%d%H%M%S', localtime(time) )
+		my $tempFile = "$URLCacheDir/tmp."
+		             . strftime ( '%m%d%H%M%S', localtime(time) )
 		             . "."
 		             # . myRand
 			     . rand
 		             ;
-		if ( LWP::Simple::mirror ($self->{request}->{file}, $tempFile) == $RC_OK ) {
-			if ( $self->{request}->{uri}->iscgi ) {
-				$self->{isCGI} = 1;
-				$self->{uris}->{tmpFile} = $sourceFile = $tempFile;
-			}
-			else {
-				MakeCacheDir ($cacheDir, $URLCacheDir);
-				rename ( $tempFile, $sourceFile );
-			}
+		if ( mirror ($URL, $tempFile) == RC_OK ) {
+			MakeCacheDir ($cacheDir, $URLCacheDir);
+			rename ( $tempFile, $sourceFile );
 			#
 			#  is sourceFile in SERA?
 			#
-			$sourceFile = LiveGeez::CacheAsSERA::Remote ( $self, $sourceFile );
-				# unless ( $self->{request}->{sysIn} && ($self->{request}->{sysIn}->{sysName} eq "sera") ); 
+			$sourceFile = LiveGeez::CacheAsSERA::HTML ( $self, $sourceFile )
+				unless ( $self->{request}->{sysIn}->{sysName} eq "sera" );
 		}
 		else {
-			return;
+			return undef;
 		}
 	}
 
-	$self->{uris}->{source} = $sourceFile;
+	$self->{sourceFile} = $sourceFile;
 
 }
 
@@ -680,16 +535,13 @@ my ( $dir, $file, $cacheDir, $cacheFileIn, $cacheFileOut, $ext );
 #------------------------------------------------------------------------------#
 sub MakeCacheDir
 {
-# my ($cacheDir, $refDir) = @_;  # always starts with "/";
+my ($cacheDir, $refDir) = @_;  # always starts with "/";
 
-	File::Path::mkpath $_[0], 0, 0755 unless -d $_[0];
-
-	return;
 	unless ( (-e $cacheDir) ) {
-		$cacheDir    =~ s/^$self->{request}->{config}->{uris}->{webroot}//;
+		$cacheDir    =~ s/^$webRoot//;
 		$cacheDir    =~ s|^/||;
 
-		my $fullPath = $self->{request}->{config}->{uris}->{webroot};
+		my $fullPath = $webRoot;
 		my (@dirs) = split ( /\//, $cacheDir );
 
 		foreach my $dir ( @dirs ) {
@@ -715,17 +567,26 @@ sub MakeCacheDir
 sub DisplayFromCache
 {
 my $self = shift;
-my $cacheFile = $self->{uris}->{cacheout};
+my $cacheFile = $self->{cacheFileOut};
 
 
-	my $fileStream 
-	= ( ( $self->{isZipped} && $self->{request}->{'x-gzip'} ) || !$self->{isZipped} )
-	  ? $cacheFile
-	  : "gzip -d --stdout $cacheFile |"
-	;
-
-	open ( FILE, "$fileStream" ) || $self->{request}->DieCgi
+	if ( $ENV{HTTP_ACCEPT_ENCODING} =~ "gzip" 
+	     && $ENV{HTTP_USER_AGENT} !~ "MSIE" ) {
+	     	$self->{request}->{'x-gzip'} = 1;
+		open ( FILE, "$cacheFile" ) || $self->{request}->DieCgi
 		 ( "!: Could Not Open Cached File: $cacheFile!\n" );
+	}
+	else {
+		my $fileStream 
+		= ( ( $self->{isZipped} && $self->{request}->{'x-gzip'}) || !$self->{isZipped} )
+		  ? "$cacheFile"
+		  : "gzip -d --stdout $cacheFile |"
+		;
+
+		open ( FILE, "$fileStream" ) || $self->{request}->DieCgi
+			 ( "!: Could Not Open Cached File: $cacheFile!\n" );
+
+	}
 
 	$self->{request}->HeaderPrint;
 
@@ -733,65 +594,7 @@ my $cacheFile = $self->{uris}->{cacheout};
 
 	close (FILE);
 
-}
-
-
-#------------------------------------------------------------------------------#
-#
-# "DisplayFromCache"
-# 
-#	Does just as the name implies.  The "cacheFileOut" string must be set
-#	before the method is called.  The file is printed to STDOUT.  Generally
-#   cached files are gzipped, DisplayFromCache will gunzip as needed.
-#
-#------------------------------------------------------------------------------#
-sub DisplayFromCacheX
-{
-my $self = shift;
-my $cacheFile = $self->{uris}->{cacheout};
-
-
-	$self->{request}->HeaderPrint;
-
-	# print STDERR "ZIP[1]: $self->{request}->{'x-gzip'}\n";
-
-	if ( $self->{request}->{apache} ) {
-		$self->{request}->HeaderPrint;
-		if ( $self->{request}->{'x-gzip'} ) {
-			my $fh = Apache::File->new( $cacheFile );
-			# print STDERR "Printing Zipped: $cacheFile\n";
-			# local $/;
-			# print Compress::Zlib::memGzip( <$fh> );
-			$self->{request}->{apache}->send_fd($fh);
-		}
-		else {
-			my $fileStream 
-			= ( ( $self->{isZipped} && $self->{request}->{'x-gzip'}) || !$self->{isZipped} )
-			  ? "$cacheFile"
-			  : "gzip -d --stdout $cacheFile |"
-			;
-			my $fh = Apache::File->new( $fileStream );
-			$self->{request}->{apache}->send_fd($fh);
-		}
-	}
-	else {
-		my $fileStream 
-		= ( ( $self->{isZipped} && $self->{request}->{'x-gzip'}) || !$self->{isZipped} )
-		  ? $cacheFile
-		  : "gzip -d --stdout $cacheFile |"
-		;
-
-		open ( FILE, "$fileStream" ) || $self->{request}->DieCgi
-			 ( "!: Could Not Open Cached File: $cacheFile!\n" );
-
-
-		$self->{request}->HeaderPrint;
-
-		$self->{request}->print ( <FILE> );
-
-		close (FILE);
-	}
-
+     	$self->{request}->{'x-gzip'} = 0;
 }
 
 
@@ -807,7 +610,7 @@ my $cacheFile = $self->{uris}->{cacheout};
 sub ReadFromCache
 {
 my $self = shift;
-my $cacheFile = $self->{uris}->{cacheout};
+my $cacheFile = $self->{cacheFileOut};
 my $fileStream;
 
 
@@ -815,10 +618,8 @@ my $fileStream;
 
 	open (FILE, "$fileStream") || $self->{request}->DieCgi
 	     ( "!: Could Not Open Cached File: $cacheFile!\n" );
-	# @gFile = <FILE>;
-	# $self->{htmlData} = join ( "", @gFile );
-	local $/ = undef;
-	$self->{htmlData} = <FILE>;
+	@gFile = <FILE>;
+	$self->{htmlData} = join ( "", @gFile );
 	close (FILE);
 
 }
@@ -827,10 +628,10 @@ my $fileStream;
 sub SaveToCache
 {
 my $self = shift;
-my $cacheFile = $self->{uris}->{cachein};
+my $cacheFile = $self->{cacheFileIn};
 
 
-	if ( $self->{request}->{apache} ) {
+	if ( $useApache ) {
 		$self->{request}->{apache}->print ( $self->{htmlData} );
 		open (CACHEFILE, ">$cacheFile") 
 		|| $self->{request}->DieCgi ( "!: Can't Open $cacheFile!\n" );
